.. OrcaNet documentation master file, created by
   sphinx-quickstart on Tue Nov  6 18:06:28 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. |vspace| raw:: latex

   \vspace{1cm}

.. image:: _static/orcanet_wide_transparent_black.png
   :height: 142px

|vspace|

.. include:: ../Readme.rst

.. toctree::
    :hidden:
    :titlesonly:

    self

.. toctree::
   :maxdepth: 2

   intro
   input_list
   lr
   modifiers
   full_example
   CONTRIBUTING


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
